@@ -6,7 +6,6 @@
 
 #include "xf86.h"
 #include "xf86_OSproc.h"
-#include "xf86_ansic.h"
 #include "xf86Priv.h"
 #include "xf86PciInfo.h"
 #include "xf86Pci.h"
@@ -301,7 +300,6 @@ Bool TDFXDRIScreenInit(ScreenPtr pScreen)
     /* Check that the GLX, DRI, and DRM modules have been loaded by testing
        for canonical symbols in each module. */
     if (!xf86LoaderCheckSymbol("GlxSetVisualConfigs")) return FALSE;
-    if (!xf86LoaderCheckSymbol("DRIScreenInit"))       return FALSE;
     if (!xf86LoaderCheckSymbol("drmAvailable"))        return FALSE;
     if (!xf86LoaderCheckSymbol("DRIQueryVersion")) {
       xf86DrvMsg(pScreen->myNum, X_ERROR,
@@ -445,7 +443,7 @@ Bool TDFXDRIScreenInit(ScreenPtr pScreen)
     xf86DrvMsg(pScreen->myNum, X_ERROR, "drmAddMap failed, disabling DRI.\n");
     return FALSE;
   }
-  xf86DrvMsg(pScreen->myNum, X_INFO, "[drm] Registers = 0x%08lx\n",
+  xf86DrvMsg(pScreen->myNum, X_INFO, "[drm] Registers = 0x%08x\n",
 	       pTDFXDRI->regs);
 
   if (!(TDFXInitVisualConfigs(pScreen))) {
@@ -595,6 +593,10 @@ TDFXDRIMoveBuffers(WindowPtr pParent, DDXPointRec ptOldOrg,
   pTDFX->AccelInfoRec->NeedToSync = TRUE;
 }
 
+/*
+ * the FullScreen DRI code is dead; this is just left in place to show how
+ * to set up SLI mode.
+ */
 static Bool
 TDFXDRIOpenFullScreen(ScreenPtr pScreen)
 {
